@@ -10,6 +10,7 @@ from python_framework.api.src.service import SecurityManager
 from python_framework.api.src.service import ApiKeyManager
 from python_framework.api.src.service import SessionManager
 from python_framework.api.src.service.openapi import OpenApiManager
+from python_framework.api.src.service import SqlAlchemyProxy
 from python_framework.api.src.service import SchedulerManager
 from python_framework.api.src.annotation.GlobalExceptionAnnotation import EncapsulateItWithGlobalException
 from python_framework.api.src.constant import ConfigurationKeyConstant, JwtConstant, HealthCheckConstant
@@ -156,6 +157,7 @@ def runApi(*args, api=None, **kwargs):
     log.success(runApi, f'Documentation will be available at {documentationUrl}')
     api.app.run(*args, **kwargs)
     SchedulerManager.shutdown(api, api.app)
+    SqlAlchemyProxy.shutdown(api, api.app)
 
 @Function
 def getApiUrl(api):
